@@ -274,6 +274,19 @@ class _ItemContext:
 
         return self._time
 
+    def _isInlineChild(self, prior):
+        if not self._obj or not prior._obj:
+            return False
+
+        if prior._obj.parent != self._obj:
+            return False
+
+        if self._treatAsSingleObject():
+            return False
+
+        role = prior._obj.getRole()
+        return role == pyatspi.ROLE_LINK
+
     def present(self, prior):
         """Presents this context to the user."""
 
@@ -296,7 +309,7 @@ class _ItemContext:
             debug.println(debug.LEVEL_INFO, msg, True)
             return False
 
-        if self._obj and self._obj != prior._obj:
+        if self._obj and self._obj != prior._obj and not self._isInlineChild(prior):
             priorObj = prior._obj or self._getContainer()
             orca.emitRegionChanged(self._obj, mode=orca.MOUSE_REVIEW)
             self._script.presentObject(self._obj, priorObj=priorObj, inMouseReview=True)
