@@ -92,14 +92,13 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         and an empty array will be returned if no label can be found.
         """
         result = []
-        acss = self.voice(speech_generator.DEFAULT)
         override = self.__overrideParagraph(obj, **args)
         label = self._script.utilities.displayedLabel(obj) or ""
         if not label and override:
             label = self._script.utilities.displayedLabel(obj.parent) or ""
         if label:
             result.append(label.strip())
-            result.extend(acss)
+            result.extend(self.voice(speech_generator.DEFAULT, obj=obj, **args))
         return result
 
     def _generateName(self, obj, **args):
@@ -117,7 +116,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         # can be removed.
         if obj.name:
             result = [obj.name]
-            result.extend(self.voice(speech_generator.DEFAULT))
+            result.extend(self.voice(speech_generator.DEFAULT, obj=obj, **args))
             return result
 
         return super()._generateName(obj, **args)
@@ -132,7 +131,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         label = self._script.utilities.displayedLabel(obj) or obj.name
         if label:
             result.append(label)
-            result.extend(self.voice(speech_generator.DEFAULT))           
+            result.extend(self.voice(speech_generator.DEFAULT, obj=obj, **args))
 
         name = obj.name
         if label == name or not name:
@@ -142,7 +141,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
 
         if name:
             result.append(name)
-            result.extend(self.voice(speech_generator.DEFAULT))
+            result.extend(self.voice(speech_generator.DEFAULT, obj=obj, **args))
 
         return result
 
@@ -150,7 +149,6 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         """Gets the label or the name if the label is not preset."""
 
         result = []
-        acss = self.voice(speech_generator.DEFAULT)
         override = self.__overrideParagraph(obj, **args)
         # Treat a paragraph which is serving as a text entry in a dialog
         # as a text object.
@@ -171,7 +169,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                 if not parentLabel and obj.name and len(obj.name):
                     result.append(obj.name)
                 if result:
-                    result.extend(acss)
+                    result.extend(self.voice(speech_generator.DEFAULT, obj=obj, **args))
         else:
             result.extend(speech_generator.SpeechGenerator._generateLabelOrName(
                 self, obj, **args))
@@ -214,7 +212,6 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             return []
 
         result = []
-        acss = self.voice(speech_generator.SYSTEM)
         if obj.description:
             # The description of some OOo paragraphs consists of the name
             # and the displayed text, with punctuation added. Try to spot
@@ -230,7 +227,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                     break
 
         if result:
-            result.extend(acss)
+            result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
         return result
 
     def _generateCurrentLineText(self, obj, **args):
@@ -249,21 +246,16 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         # together in the scripts. In addition, the voice crap needs to go
         # here. Then it needs to be removed from the scripts.
         [text, caretOffset, startOffset] = self._script.getTextLineAtCaret(obj)
-        voice = self.voice(string=text)
-        text = self._script.utilities.adjustForLinks(obj, text, startOffset)
-        text = self._script.utilities.adjustForRepeats(text)
         if not text:
             result = [messages.BLANK]
-        else:
-            result = [text]
-        result.extend(voice)
+            result.extend(self.voice(string=text, obj=obj, **args))
+            return result
 
-        return result
+        return super()._generateCurrentLineText(obj, **args)
 
     def _generateToggleState(self, obj, **args):
         """Treat toggle buttons in the toolbar specially. This is so we can
         have more natural sounding speech such as "bold on", "bold off", etc."""
-        acss = self.voice(speech_generator.SYSTEM)
         result = []
         role = args.get('role', obj.getRole())
         if role == pyatspi.ROLE_TOGGLE_BUTTON \
@@ -272,7 +264,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                 result.append(messages.ON)
             else:
                 result.append(messages.OFF)
-            result.extend(acss)
+            result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
         elif role == pyatspi.ROLE_TOGGLE_BUTTON:
             result.extend(speech_generator.SpeechGenerator._generateToggleState(
                 self, obj, **args))
@@ -299,7 +291,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         text = self._script.utilities.displayedText(rowHeader)
         if text:
             result.append(text)
-            result.extend(self.voice(speech_generator.DEFAULT))
+            result.extend(self.voice(speech_generator.DEFAULT, obj=obj, **args))
 
         return result
 
@@ -321,7 +313,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         text = self._script.utilities.displayedText(columnHeader)
         if text:
             result.append(text)
-            result.extend(self.voice(speech_generator.DEFAULT))
+            result.extend(self.voice(speech_generator.DEFAULT, obj=obj, **args))
 
         return result
 
@@ -337,7 +329,6 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             return []
 
         result = []
-        acss = self.voice(speech_generator.SYSTEM)
         try:
             text = obj.queryText()
             objectText = \
@@ -357,7 +348,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             if tooLongCount > 0:
                 result = [messages.charactersTooLong(tooLongCount)]
         if result:
-            result.extend(acss)
+            result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
         return result
 
     def _generateHasFormula(self, obj, **args):
@@ -368,7 +359,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         text = self._script.utilities.displayedText(inputLine)
         if text and text.startswith("="):
             result = [messages.HAS_FORMULA]
-            result.extend(self.voice(speech_generator.SYSTEM))
+            result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
             return result
 
         return []
