@@ -293,6 +293,8 @@ class Script(default.Script):
             else:
                 speech.speak(self.speechGenerator.generateSpeech(obj))
 
+        self.pointOfReference["lastTextUnitSpoken"] = "char"
+
     def sayWord(self, obj):
         """Speaks the word at the caret.
 
@@ -309,6 +311,8 @@ class Script(default.Script):
         for (obj, start, end, string) in objects:
             self.sayPhrase(obj, start, end)
 
+        self.pointOfReference["lastTextUnitSpoken"] = "word"
+
     def sayLine(self, obj):
         """Speaks the line at the caret.
 
@@ -334,6 +338,8 @@ class Script(default.Script):
             if obj.getRole() in rolesToSpeak:
                 speech.speak(self.speechGenerator.getRoleName(obj))
 
+        self.pointOfReference["lastTextUnitSpoken"] = "line"
+
     def sayPhrase(self, obj, startOffset, endOffset):
         """Speaks the text of an Accessible object between the given offsets.
 
@@ -349,7 +355,7 @@ class Script(default.Script):
 
         phrase = self.utilities.substring(obj, startOffset, endOffset)
         if len(phrase) and phrase != "\n":
-            voice = self.speechGenerator.voice(string=phrase)
+            voice = self.speechGenerator.voice(obj=obj, string=phrase)
             phrase = self.utilities.adjustForRepeats(phrase)
             links = [x for x in obj if x.getRole() == pyatspi.ROLE_LINK]
             if links:
@@ -360,6 +366,8 @@ class Script(default.Script):
             #
             self.sayCharacter(obj)
 
+        self.pointOfReference["lastTextUnitSpoken"] = "phrase"
+
     def skipObjectEvent(self, event):
         """Gives us, and scripts, the ability to decide an event isn't
         worth taking the time to process under the current circumstances.
