@@ -81,14 +81,14 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             if priorDoc != doc and not self._script.utilities.getDocumentForObject(doc):
                 result = [super()._generateName(doc)]
 
-        if self._script.utilities.isLink(obj) \
-           or self._script.utilities.isLandmark(obj) \
-           or self._script.utilities.isMath(obj) \
-           or obj.getRole() in [pyatspi.ROLE_TOOL_TIP, pyatspi.ROLE_STATUS_BAR]:
+        if not self._script.utilities.getTable(obj) \
+           and (self._script.utilities.isLink(obj) \
+                or self._script.utilities.isLandmark(obj) \
+                or self._script.utilities.isMath(obj) \
+                or obj.getRole() in [pyatspi.ROLE_TOOL_TIP, pyatspi.ROLE_STATUS_BAR]):
             return result
 
-        args['stopAtRoles'] = [pyatspi.ROLE_DOCUMENT_FRAME,
-                               pyatspi.ROLE_DOCUMENT_WEB,
+        args['stopAtRoles'] = [pyatspi.ROLE_DOCUMENT_WEB,
                                pyatspi.ROLE_EMBEDDED,
                                pyatspi.ROLE_INTERNAL_FRAME,
                                pyatspi.ROLE_MATH,
@@ -158,6 +158,9 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         if not self._script.utilities.inDocumentContent(obj):
             return []
 
+        if self._script.utilities.isFeedArticle(obj):
+            return []
+
         if not args.get('mode', None):
             args['mode'] = self._mode
 
@@ -324,6 +327,19 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         if priorObj and priorObj in self._script.utilities.labelsForObject(obj):
             return []
 
+        descendant = args.get("ancestorOf")
+        if descendant and priorObj and obj.name and obj.name == priorObj.name:
+            msg = "WEB: %s's ancestor %s has same name as priorObj %s. Not generating labelOrName." \
+                % (descendant, obj, priorObj)
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return []
+
+        role = args.get('role', obj.getRole())
+        if role == pyatspi.ROLE_MENU and self._script.utilities.isPopupMenuForCurrentItem(obj):
+            msg = "WEB: %s is popup menu for current item." % obj
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return []
+
         if self._script.utilities.isContentEditableWithEmbeddedObjects(obj) \
            or self._script.utilities.isDocument(obj):
             lastKey, mods = self._script.utilities.lastKeyAndModifiers()
@@ -451,19 +467,31 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         # We handle things even for non-document content due to issues in
         # other toolkits (e.g. exposing list items to us that are not
         # exposed to sighted users)
+        roles = [pyatspi.ROLE_DESCRIPTION_LIST,
+                 pyatspi.ROLE_LIST,
+                 pyatspi.ROLE_LIST_BOX,
+                 'ROLE_FEED']
         role = args.get('role', obj.getRole())
-        if role not in [pyatspi.ROLE_LIST, pyatspi.ROLE_LIST_BOX]:
+        if role not in roles:
             return super()._generateNumberOfChildren(obj, **args)
 
         setsize = self._script.utilities.getSetSize(obj[0])
         if setsize is None:
-            children = [x for x in obj if x.getRole() == pyatspi.ROLE_LIST_ITEM]
+            if self._script.utilities.isDescriptionList(obj):
+                children = self._script.utilities.descriptionListTerms(obj)
+            elif role in [pyatspi.ROLE_LIST, pyatspi.ROLE_LIST_BOX]:
+                children = [x for x in obj if x.getRole() == pyatspi.ROLE_LIST_ITEM]
             setsize = len(children)
 
         if not setsize:
             return []
 
-        result = [messages.listItemCount(setsize)]
+        if self._script.utilities.isDescriptionList(obj):
+            result = [messages.descriptionListTermCount(setsize)]
+        elif role == 'ROLE_FEED':
+            result = [messages.feedArticleCount(setsize)]
+        else:
+            result = [messages.listItemCount(setsize)]
         result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
         return result
 
@@ -686,6 +714,12 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         if obj.getRole() in menuRoles:
             return super()._generatePositionInList(obj, **args)
 
+        if obj.getRole() == pyatspi.ROLE_LIST_ITEM:
+            thisObjIndex = args.get('index', 0)
+            objCount = args.get('total', 1)
+            if thisObjIndex + 1 < objCount:
+                return []
+
         if self._script.utilities.isEditableComboBox(obj):
             return []
 
@@ -700,13 +734,19 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
 
         position = int(position)
         total = int(total)
-        if position < 0 or total < 0:
+        if position < 0:
             return []
 
+        stringType = 'groupindex'
+        if total < 0:
+            if not self._script.utilities.setSizeUnknown(obj):
+                return []
+            stringType += 'totalunknown'
+
         result = []
         result.append(self._script.formatting.getString(
             mode='speech',
-            stringType='groupindex') \
+            stringType=stringType) \
             % {"index" : position,
                "total" : total})
         result.extend(self.voice(speech_generator.SYSTEM, obj=obj, **args))
@@ -823,7 +863,8 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
 
         if not result:
             if self._script.inSayAll(treatInterruptedAsIn=False) \
-               or not _settingsManager.getSetting('speakBlankLines'):
+               or not _settingsManager.getSetting('speakBlankLines') \
+               or args.get('formatType') == 'ancestor':
                 string = ""
             else:
                 string = messages.BLANK
